
.. _installation:

************
Installation
************


General installation
====================

1. Install :xref:`miniconda`/:xref:`conda_installation`
2. Create new environment and install MFA: :code:`conda create -n env -c conda-forge kalpy`

   a.  You can enable the :code:`conda-forge` channel by default by running :code:`conda config --add channels conda-forge` in order to omit the :code:`-c conda-forge` from these commands

3. Ensure you're in the new environment created (:code:`conda activate env`)
